<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>面容</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>請驗證人臉ID</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>人臉ID已鎖定，請輸入密碼</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>設備不可用！</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>請驗證指紋</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>指紋已鎖定，請輸入密碼</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>虹膜</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>請驗證虹膜ID</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>虹膜ID已鎖定，請輸入密碼</translation>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation>請插入安全密鑰</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message>
        <source>Verification failed</source>
        <translation>驗證失敗</translation>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation>正在識別安全密鑰</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>密碼錯誤</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>請輸入密碼</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>請1分鐘後再試</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>重置密碼</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘記密碼？</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>請1分鐘後再試</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>重置密碼</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘記密碼？</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN錯誤</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>需要使用UKEY認證</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>識別到UKEY，需要輸入PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>請1分鐘後再試</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>賬戶</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>密碼將於%n天後過期，請及時修改密碼</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>密碼已過期，請修改</translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation>您的密碼已過期，請聯繫管理員修改密碼</translation>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation>該設備已被鎖定，請聯繫管理員</translation>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>賬戶錯誤</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>密碼錯誤</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation>標準模式</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>鎖屏</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>鎖屏失敗</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>指紋密碼驗證超時，請手動輸入密碼</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>指紋解鎖失敗</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>此電腦還有以上賬戶在登錄，關閉電腦會導致其數據丟失，是否要關閉此電腦？</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>此電腦還有以上賬戶在登錄，重啟電腦會導致其數據丟失，是否要重啟此電腦？</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>您已開啟高級別等級保護，無法切換Wayland模式，請於“安全中心”關閉高級別等級保護後再試</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>鎖定螢幕</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>註銷</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>切換使用者</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>切換系統</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>更新並關機</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>更新並重啟</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>啟動系統監視器</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>获取验证码</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation>請插入電源後再開始更新</translation>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation>請選擇登錄的賬戶</translation>
    </message>
    <message>
        <source>Local Account</source>
        <translation>本地賬戶</translation>
    </message>
    <message>
        <source>Domain Account</source>
        <translation>域賬戶</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>以上程序阻止關機，強制關機可能會導致其數據丟失。</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>您可以點擊“取消”然後關閉這些程序。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>以上程序阻止重啟，強制重啟可能會導致其數據丟失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>以上程序阻止待機，強制待機可能會導致其數據丟失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>以上程序阻止休眠，強制休眠可能會導致其數據丟失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>以上程序阻止註銷，強制註銷可能會導致其數據丟失。</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>註銷</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>您確定要關機嗎？</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>您確定要重啟嗎？</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>您確定要註銷嗎？</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>更新並關機</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>更新並重啟</translation>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation>正在關閉以上程序並關機，請稍後...</translation>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation>正在關閉以上程序並重啟，請稍後...</translation>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation>正在關閉以上程序並註銷，請稍後...</translation>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>關閉</translation>
    </message>
</context>
</TS>